<?php

namespace B2buy\Agent\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use B2buy\Agent\Http\Requests\AgentRequest;
use B2buy\Agent\Interfaces\AgentRepositoryInterface;
use B2buy\Agent\Models\Agent;
use B2buy\Agent\Forms\Agent as Form;

/**
 * APIController  class for agent.
 */
class AgentAPIController extends BaseController
{

    /**
     * Initialize agent resource controller.
     *
     * @param type AgentRepositoryInterface $agent
     *
     * @return null
     */
    public function __construct(AgentRepositoryInterface $agent)
    {
        parent::__construct();
        $this->repository = $agent;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Agent\Repositories\Criteria\AgentResourceCriteria::class);
    }

    /**
     * Display a list of agent.
     *
     * @return Response
     */
    public function index(AgentRequest $request)
    {
        return $this->repository
            ->setPresenter(\B2buy\Agent\Repositories\Presenter\AgentPresenter::class)
            ->paginate();
    }

    /**
     * Display agent.
     *
     * @param Request $request
     * @param Model   $agent
     *
     * @return Response
     */
    public function show(AgentRequest $request, Agent $agent)
    {
        return $agent->setPresenter(\B2buy\Agent\Repositories\Presenter\AgentListPresenter::class);
        ;
    }

    /**
     * Create new agent.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AgentRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('agent::agent.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('agent/agent/' . $agent->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('agent/agent');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the agent.
     *
     * @param Request $request
     * @param Model   $agent
     *
     * @return Response
     */
    public function update(AgentRequest $request, Agent $agent)
    {
        try {
            $data = $request->all();

            $agent->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('agent::agent.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('agent/agent/' . $agent->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('agent/agent/' . $agent->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the agent.
     *
     * @param Model   $agent
     *
     * @return Response
     */
    public function destroy(AgentRequest $request, Agent $agent)
    {
        try {
            $agent->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('agent::agent.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('agent/agent/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('agent/agent/' . $agent->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
