<?php

namespace B2buy\Agent\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Agent\Models\Agent;

class AgentPolicy
{

    /**
     * Determine if the given user can view the agent.
     *
     * @param UserPolicy $user
     * @param Agent $agent
     *
     * @return bool
     */
    public function view(UserPolicy $user, Agent $agent)
    {
        if ($user->canDo('agent.agent.view') && $user->isAdmin()) {
            return true;
        }

        return $agent->user_id == user_id() && $agent->user_type == user_type();
    }

    /**
     * Determine if the given user can create a agent.
     *
     * @param UserPolicy $user
     * @param Agent $agent
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('agent.agent.create');
    }

    /**
     * Determine if the given user can update the given agent.
     *
     * @param UserPolicy $user
     * @param Agent $agent
     *
     * @return bool
     */
    public function update(UserPolicy $user, Agent $agent)
    {
        if ($user->canDo('agent.agent.edit') && $user->isAdmin()) {
            return true;
        }

        return $agent->user_id == user_id() && $agent->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given agent.
     *
     * @param UserPolicy $user
     * @param Agent $agent
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Agent $agent)
    {
        return $agent->user_id == user_id() && $agent->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given agent.
     *
     * @param UserPolicy $user
     * @param Agent $agent
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Agent $agent)
    {
        if ($user->canDo('agent.agent.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given agent.
     *
     * @param UserPolicy $user
     * @param Agent $agent
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Agent $agent)
    {
        if ($user->canDo('agent.agent.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
